@@ -31,7 +31,7 @@ TestExtraNewAttributeCloner
 
 =head1 VERSION
 
-0.19.5
+0.2
 
 =head1 SYNOPSIS
 
